/*************************************
 * Message header:
 *   - timestamp: 8 bytes
 *   - sequence: 2 bytes (0..65535)
 *   - type: 1 byte (1 - send ; 2 - sendAndListen ; 3 - reply ; 4 - replyAndListen)
 *   - if (type == 3 || type == 4)
 *     - source timestamp: 8 bytes
 *     - source sequence: 2 bytes
 *
 * SYSTEM MESSAGES
 *   - body = [1] => ping
 *
 *
 * https://javascript.info/arraybuffer-binary-arrays
 *************************************/
export declare const MESSAGE_SEND = 1;
export declare const MESSAGE_SEND_AND_LISTEN = 2;
export declare const MESSAGE_REPLY = 3;
export declare const MESSAGE_REPLY_AND_LISTEN = 4;
export declare const SYSTEM_MESSAGE_PING = 1;
export declare const SYSTEM_MESSAGE_IM_READY = 2;
export declare class Message {
    private _timestamp;
    private _sequence;
    private _type;
    private _sourceTimestamp?;
    private _sourceSequence?;
    private _body;
    private _fullMessage;
    private _clockDiff;
    static parse(fullMessage: ArrayBuffer): Message;
    constructor(body: ArrayBuffer, timestamp: number, sequence: number, type: number, sourceTimestamp?: number, _sourceSequence?: number);
    get timestamp(): number;
    get sequence(): number;
    get type(): number;
    get sourceTimestamp(): number | undefined;
    get sourceSequence(): number | undefined;
    get body(): ArrayBuffer;
    get fullMessage(): ArrayBuffer;
    get key(): string;
    get sourceKey(): string;
    get awaitReply(): boolean;
    get clockDiff(): number | undefined;
    set clockDiff(value: number | undefined);
    get timestampToLocalTime(): number | undefined;
}
